@@ -7,8 +7,7 @@ from pinecone.protos import core_pb2
 from pinecone.utils import module_name, get_memory_usage
 from pinecone.utils.constants import PERSISTENT_VOLUME_MOUNT, MEMORY_LIMIT_MB
 
-
-import os.path
+import os.path, os
 import json
 import argparse
 from typing import Dict, Union, Optional
@@ -140,11 +139,19 @@ class Function:
 
     @property
     def default_persistent_dir(self):
-        data_dir = PERSISTENT_VOLUME_MOUNT if os.path.exists(PERSISTENT_VOLUME_MOUNT) else '/tmp/data'
+        persistent_mount = os.path.exists(PERSISTENT_VOLUME_MOUNT) and os.access(PERSISTENT_VOLUME_MOUNT, os.W_OK)
+        data_dir = PERSISTENT_VOLUME_MOUNT if persistent_mount else '/tmp/data'
         persistent_dir = os.path.join(data_dir, os.environ.get('HOSTNAME'))
         os.makedirs(persistent_dir, exist_ok=True)
         return os.path.join(persistent_dir, self.name)
 
+    @property
+    def default_volatile_dir(self):
+        data_dir = '/tmp/volatile_data'
+        volatile = os.path.join(data_dir, os.environ.get('HOSTNAME'))
+        os.makedirs(volatile, exist_ok=True)
+        return os.path.join(volatile, self.name)
+
     @property
     def full(self) -> bool:
         if MEMORY_LIMIT_MB == 0:  # no limit
