@@ -14,9 +14,11 @@ class NamespacedEngine(Engine):
     """
 
     SUPPORTED_ENGINES = {'approximated': 'pinecone_engine.functions.engine.approximated.ApproximatedEngine',
-                         'exact': 'pinecone_engine.functions.engine.exact.ExactEngine'}
+                         'exact': 'pinecone_engine.functions.engine.exact.ExactEngine',
+                         'exactly': 'pinecone_engine.functions.engine.exact.ExactlyEngine'}
     SUPPORTED_ENGINE_IMAGES = {'approximated': 'pinecone/engine/approximated',
-                               'exact': 'pinecone/engine/exact'}
+                               'exact': 'pinecone/engine/exact',
+                               'exactly': 'pinecone/engine/exactly'}
 
     @property
     def image(self):
