@@ -2,9 +2,10 @@
 # Copyright (c) 2020-2021 Pinecone Systems Inc. All right reserved.
 #
 
-from pinecone.network.zmq import ZMQServlet, Socket, SocketType
+from pinecone.network.zmq import Socket, SocketType
 from pinecone.network.zmq.spec import ServletSpec
-from pinecone.utils import constants, load_numpy, get_version
+from pinecone.network.zmq.servlet import ZMQServlet
+from pinecone.utils import constants
 from pinecone.protos import core_pb2
 
 import docker
@@ -74,7 +75,8 @@ class HubModel(abc.ABC):
         ports = {constants.ZMQ_PORT_IN: constants.ZMQ_PORT_IN, constants.ZMQ_SECONDARY_PORT: constants.ZMQ_SECONDARY_PORT}
         command = ['python3', '-m', 'pinecone.functions.model', *self.to_args()]
         self.docker_client = docker.from_env()
-        self.container = self.docker_client.containers.run(self.image_uri(), command, ports=ports, detach=True)
+        self.container = self.docker_client.containers.run(self.image_uri(), command, ports=ports, detach=True,
+                                                           environment=['PYTHONUNBUFFERED==1'])
         time.sleep(1)
         try:
             loop = asyncio.get_event_loop()
