@@ -5,7 +5,7 @@
 from pinecone.protos import core_pb2
 from pinecone.utils.exceptions import RestartException
 from pinecone.network.zmq.spec import ServletSpec
-from pinecone.network.zmq import ZMQServlet
+from pinecone.network.zmq.servlet import ZMQServlet
 from pinecone.utils.constants import RECV_TIMEOUT
 from pinecone.network.zmq.wal import WALServlet
 
