@@ -5,9 +5,9 @@
 from .exceptions import InvalidOffsetException
 from pinecone.utils import replica_kube_hostname, replica_name
 from pinecone.protos import core_pb2
-from pinecone.network.zmq import ZMQServlet
+from pinecone.network.zmq.servlet import ZMQServlet
 from pinecone.utils import open_or_create, get_hostname, wal
-from pinecone.utils.constants import MAX_CLIENTS, SEND_TIMEOUT, RECV_TIMEOUT, ZMQ_LOG_PORT, MAX_MSGS_PENDING
+from pinecone.utils.constants import MAX_CLIENTS, SEND_TIMEOUT, ZMQ_LOG_PORT, MAX_MSGS_PENDING
 from pinecone.network.zmq.spec import ServletSpec, SocketType, Socket
 
 from typing import Iterable, Tuple
