@@ -12,9 +12,9 @@ MAX_RETRY_MSG = 100
 DEFAULT_TIMEOUT = 2
 GATEWAY_NAME = 'gatewayrouter'
 MAX_MSG_SIZE = 64 * 1024 * 1024
-OUT_POOL_SIZE = 100
 MAX_MSGS_PER_CONNECTION = 100
 MAX_SOCKS_OPEN = 1000
+DNS_TTL = 1
 
 ZMQ_CONTROL_PORT = os.environ.get('ZMQ_CONTROL_PORT', 5559)
 ZMQ_PORT_IN = os.environ.get('ZMQ_PORT_IN', 5557)
